package edu.colorado.androidontwitter;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.net.HttpURLConnection;
import java.net.MalformedURLException;
import java.net.URL;

import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

import android.app.Activity;
import android.app.ProgressDialog;
import android.os.AsyncTask;
import android.os.Bundle;
import android.view.Menu;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.ArrayAdapter;
import android.widget.Button;
import android.widget.ListView;


public class Main extends Activity implements OnClickListener {

    private GetTweets get_tweets_task;

    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);
        
        ArrayAdapter<String> adapter = new ArrayAdapter<String>(this, R.layout.list_item);
        adapter.add("No Tweets");

        ListView filters = (ListView) findViewById(R.id.tweets);
        filters.setAdapter(adapter);

        Button get_button =  (Button) findViewById(R.id.get_tweets);

        get_button.setOnClickListener(this);
        
    }
    
    public void onClick(View v) {
        switch (v.getId()) {
            case R.id.get_tweets:
                get_tweets_task = new GetTweets();
                get_tweets_task.execute();
                        break;
        }
    }
    
    private class GetTweets extends AsyncTask<Object, String, Boolean> {
    	private ProgressDialog progressDialog;
    	
    	@Override
    	protected void onPreExecute() {
    		progressDialog = ProgressDialog.show(Main.this, "Tweets Containing Android", "Downloading tweets...", true, true);
    	}
    	
    	@Override
    	protected void onPostExecute(Boolean result) {
    		progressDialog.dismiss();
    	}

		@Override
		protected Boolean doInBackground(Object... params) {
			HttpURLConnection con = null;
			try {
				URL url = new URL("http://search.twitter.com/search.json?q=Android");
				
				con = (HttpURLConnection) url.openConnection();
				con.setReadTimeout(10000);
				con.setConnectTimeout(15000);
				
				con.setRequestMethod("GET" );
				
				con.setDoInput(true);
				
				con.connect();
				
				BufferedReader reader = new BufferedReader( new InputStreamReader(con.getInputStream(), "UTF-8"));
				String payload = "";
				String line = reader.readLine();
				while (line != null) {
					payload += line;
					line = reader.readLine();
				}
				reader.close();
				System.out.println("Payload: " + payload);
				// Parse result
				JSONObject jsonObject = new JSONObject(payload);
				JSONArray items = jsonObject.getJSONArray("results");
				int length = items.length();
				String[] tweets = new String[length];
				
				for (int i = 0; i < length; i++) {
					JSONObject tweet = items.getJSONObject(i);
					tweets[i] = tweet.getString("text");
				}
				
				publishProgress(tweets);
				
				
			} catch (MalformedURLException e) {
				// TODO Auto-generated catch block
				e.printStackTrace();
			} catch (IOException e) {
				// TODO Auto-generated catch block
				e.printStackTrace();
			} catch (JSONException e) {
				// TODO Auto-generated catch block
				e.printStackTrace();
			}
			return true;
		}
		
	    @Override
	    protected void onProgressUpdate(String... values) {
	        ArrayAdapter<String> adapter = new ArrayAdapter<String>(Main.this, R.layout.list_item);
	        for (String tweet : values) {
	        	adapter.add(tweet);
	        }
	        ListView tweets = (ListView) Main.this.findViewById(R.id.tweets);
	        tweets.setAdapter(adapter);
	        
	    }

    }


    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        getMenuInflater().inflate(R.menu.activity_main, menu);
        return true;
    }
}
